/*
 * Copyright (C) 2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.acidhouse.jazzmaster;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import org.eiichiro.jazzmaster.kernel.Binding;

/**
 * {@code Strong} is a binding annotation to composite 
 * {@code AppEngineStrongDatastoreSession} into Jazzmaster component.
 * You can use {@code AppEngineStrongDatastoreSession} on Jazzmaster like this: 
 * <pre>
 * {@code @Implementation}
 * public class Service1Impl implements Service1 {
 * 
 * 	// If no binding annotation is specified, Jazzmaster composites 
 * 	// AppEngineDatastoreSession ("Loose" session) into this property.
 * 	{@code @Consumes} private DatastoreSession session;
 * 
 * 	// {@code @Strong} binding annotation means Jazzmaster composites 
 * 	// AppEngineStrongDatastoreSession ("Strong" session) into this property.
 * 	{@code @Consumes} {@code @Strong} private DatastoreSession strongSession;
 * 
 * 	{@code @Override}
 * 	public List&lt;Entity1&gt; getEntity1() {
 * 		Entity1_ entity1 = metamodel(Entity1.class);
 * 		return session.get(Entity1.class)
 * 		.filter(entity1.i.greaterThan(0))
 * 		.execute();
 * 	}
 * 
 * 	{@code @Override}
 * 	public void putEntity1(Entity1... entity1s) {
 * 		session.put(entity1s);
 * 	}
 * }
 * </pre>
 * 
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Binding
public @interface Strong {}
