/*
 * Copyright (C) 2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.acidhouse.jazzmaster;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

import org.eiichiro.jazzmaster.bus.Interception;

/**
 * {@code Transactional} is a interception annotation to control transaction 
 * declaratively. You can do "Declarative transaction" on Acid House and 
 * Jazzmaster like this: 
 * <pre>
 * public interface Service1 {
 * 
 * 	public List&lt;Entity1&gt; getEntity1();
 * 
 * 	{@code @Transactional} public void putEntity1(Entity1... entity1s);
 * 
 * }
 * </pre>
 * 
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
@Documented
@Retention(RetentionPolicy.RUNTIME)
@Interception
public @interface Transactional {}
